==> open-xchange-core_7.10.0.orig.tar.bz2: open-xchange-core-7.10.0/com.openexchange.chronos/src/com/openexchange/chronos/AlarmTriggerField.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos;


/**
 * {@link AlarmTriggerField} contains the available fields of the {@link AlarmTrigger}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.10.0
 */
public enum AlarmTriggerField {
    /**
     * The calendar account id
     */
    ACCOUNT,
    /**
     * The alarm action
     */
    ACTION,
    /**
     * The id of the alarm
     */
    ALARM_ID,
    /**
     * The context id
     */
    CONTEXT_ID,
    /**
     * The id of the event the alarm belongs to
     */
    EVENT_ID,
    /**
     * A flag indicating whether the trigger is already triggered or not
     */
    PUSHED,
    /**
     * The recurrence identifier of the targeted event.
     */
    RECURRENCE_ID,
    /**
     * The trigger time
     */
    TIME,
    /**
     * The user id
     */
    USER_ID,
    /**
     * The folder of the event
     */
    FOLDER,
    /**
     * The timezone used for floating events
     */
    FLOATING_TIMEZONE,
    /**
     * The date and time the trigger time is calculated on
     */
    RELATED_TIME

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.chronos/src/com/openexchange/chronos/AlarmTriggerField.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos;


/**
 * {@link AlarmTriggerField} contains the available fields of the {@link AlarmTrigger}
 *
 * @author <a href="mailto:kevin.ruthmann@open-xchange.com">Kevin Ruthmann</a>
 * @since v7.10.0
 */
public enum AlarmTriggerField {
    /**
     * The calendar account id
     */
    ACCOUNT,
    /**
     * The alarm action
     */
    ACTION,
    /**
     * The id of the alarm
     */
    ALARM_ID,
    /**
     * The context id
     */
    CONTEXT_ID,
    /**
     * The id of the event the alarm belongs to
     */
    EVENT_ID,
    /**
     * A flag indicating whether the trigger is already triggered or not
     */
    PUSHED,
    /**
     * The recurrence identifier of the targeted event.
     */
    RECURRENCE_ID,
    /**
     * The trigger time
     */
    TIME,
    /**
     * The user id
     */
    USER_ID,
    /**
     * The folder of the event
     */
    FOLDER,
    /**
     * The timezone used for floating events
     */
    FLOATING_TIMEZONE,
    /**
     * The date and time the trigger time is calculated on
     */
    RELATED_TIME,
    /**
     * The processed field. Contains information about whether the trigger is already picked up by a node to perform mail delivery.
     */
    PROCESSED

}
